Indices and tables — lsm-db 0.1.0 documentation

Fast Python bindings for SQLite4’s LSM key/value store.

Features:

- Embedded zero-conf database.
- Keys support in-order traversal using cursors.
- Transactional (including nested transactions).
- Single writer/multiple reader MVCC based transactional concurrency model.
- On-disk database stored in a single file.
- Data is durable in the face of application or power failure.
- Thread-safe.

The source for Python lsm-db is hosted on GitHub.

Note

If you encounter any bugs in the library, please open an issue, including a description of the bug and any related traceback.

Contents:

- Installation
- Quick-start
  - Key/Value Features
  - Slices and Iteration
  - Cursors
  - Transactions
- API Documentation
  - Constants

# Indices and tables

- Index
- Module Index
- Search Page